#[repr(u8)]pub enum DiagnosticPowerModeCode {
NotReady = 0,
Ready = 1,
NotSupported = 2,
Reserved(u8),
}Expand description
Identifies whether or not the vehicle is in diagnostic power mode and ready to perform reliable diagnostics.
Variants
NotReady = 0
The vehicle is not currently able to perform reliable diagnostics.
Ready = 1
The vehicle is ready to perform reliable diagnostics.
NotSupported = 2
This entity does not report power mode information.
Reserved(u8)
A power mode value outside the range this crate models.